@@ -23,8 +23,9 @@ from pygls.exceptions import (
     ValidationError,
 )
 from pygls.feature_manager import has_ls_param_or_annotation, wrap_with_server
-from pygls.lsp import methods
-from pygls.lsp.types import CompletionOptions
+from lsprotocol import types
+from typeguard import TypeCheckError
+from typeguard._utils import qualified_name
 
 
 def test_has_ls_param_or_annotation():
@@ -72,20 +73,20 @@ def test_register_commands(feature_manager):
 
 
 def test_register_feature_with_valid_options(feature_manager):
-    options = CompletionOptions(trigger_characters=["!"])
+    options = types.CompletionOptions(trigger_characters=["!"])
 
-    @feature_manager.feature(methods.COMPLETION, options)
+    @feature_manager.feature(types.TEXT_DOCUMENT_COMPLETION, options)
     def completions():
         pass
 
     reg_features = feature_manager.features.keys()
     reg_feature_options = feature_manager.feature_options.keys()
 
-    assert methods.COMPLETION in reg_features
-    assert methods.COMPLETION in reg_feature_options
+    assert types.TEXT_DOCUMENT_COMPLETION in reg_features
+    assert types.TEXT_DOCUMENT_COMPLETION in reg_feature_options
 
-    assert feature_manager.features[methods.COMPLETION] is completions
-    assert feature_manager.feature_options[methods.COMPLETION] is options
+    assert feature_manager.features[types.TEXT_DOCUMENT_COMPLETION] is completions
+    assert feature_manager.feature_options[types.TEXT_DOCUMENT_COMPLETION] is options
 
 
 def test_register_feature_with_wrong_options(feature_manager):
@@ -93,34 +94,34 @@ def test_register_feature_with_wrong_options(feature_manager):
         pass
 
     with pytest.raises(
-        TypeError,
+        TypeCheckError,
         match=(
-            f'Options of method "{methods.COMPLETION}" should be instance of type '
-            "<class 'pygls.lsp.types.language_features.completion.CompletionOptions'>"
+            f'{qualified_name(Options)} is not an instance of '
+            "lsprotocol.types.CompletionOptions"
         ),  # noqa
     ):
 
-        @feature_manager.feature(methods.COMPLETION, Options())
+        @feature_manager.feature(types.TEXT_DOCUMENT_COMPLETION, Options())
         def completions():
             pass
 
 
 def test_register_features(feature_manager):
-    @feature_manager.feature(methods.COMPLETION)
+    @feature_manager.feature(types.TEXT_DOCUMENT_COMPLETION)
     def completions():
         pass
 
-    @feature_manager.feature(methods.CODE_LENS)
+    @feature_manager.feature(types.TEXT_DOCUMENT_CODE_LENS)
     def code_lens():
         pass
 
     reg_features = feature_manager.features.keys()
 
-    assert methods.COMPLETION in reg_features
-    assert methods.CODE_LENS in reg_features
+    assert types.TEXT_DOCUMENT_COMPLETION in reg_features
+    assert types.TEXT_DOCUMENT_CODE_LENS in reg_features
 
-    assert feature_manager.features[methods.COMPLETION] is completions
-    assert feature_manager.features[methods.CODE_LENS] is code_lens
+    assert feature_manager.features[types.TEXT_DOCUMENT_COMPLETION] is completions
+    assert feature_manager.features[types.TEXT_DOCUMENT_CODE_LENS] is code_lens
 
 
 def test_register_same_command_twice_error(feature_manager):
@@ -140,11 +141,11 @@ def test_register_same_feature_twice_error(feature_manager):
 
     with pytest.raises(FeatureAlreadyRegisteredError):
 
-        @feature_manager.feature(methods.CODE_ACTION)
+        @feature_manager.feature(types.TEXT_DOCUMENT_CODE_ACTION)
         def code_action1():  # pylint: disable=unused-variable
             pass
 
-        @feature_manager.feature(methods.CODE_ACTION)
+        @feature_manager.feature(types.TEXT_DOCUMENT_CODE_ACTION)
         def code_action2():  # pylint: disable=unused-variable
             pass
 
